import json

class Configuration(object):
    def __init__(self, default):
        self.default = default
        self.current = default

    def loadFromFile(self, fn):
        with open(fn) as f:
            return json.loads(fn.read())
